@@ -5,6 +5,10 @@ from grebble_flow.processors.base import BaseFlowProcessor, FlowResponse
 
 @dataclass
 class Attributes:
+    """
+    Args:
+       name (str): Text name description
+    """
     name: str
 
 
