@@ -10,7 +10,7 @@ def install_proto():
     proto_include = pkg_resources.resource_filename(
         "grebble_flow", "proto"
     )
-    for file in ["grebble_flow/grpc/generated/internal/v1/app.proto", "grebble_flow/grpc/generated/internal/v1/processor.proto"]:
+    for file in ["grebble_flow/grpc/generated/inner/v1/app.proto", "grebble_flow/grpc/generated/inner/v1/processor.proto"]:
         grpc_tools.protoc.main(
             [
                 "grpc_tools.protoc",
