@@ -2,7 +2,7 @@ import logging
 from concurrent import futures
 
 import grpc
-from grebble_flow.grpc.generated.internal.v1 import processor_pb2_grpc, app_pb2_grpc
+from grebble_flow.grpc.generated.inner.v1 import processor_pb2_grpc, app_pb2_grpc
 from grebble_flow.grpc.service.app import AppService
 from grebble_flow.grpc.service.processor import ProcessorService
 
