@@ -1,8 +1,8 @@
 import json
 
-from grebble_flow.grpc.generated.internal.v1.processor_pb2 import FlowExecuteResponse
+from grebble_flow.grpc.generated.inner.v1.processor_pb2 import FlowExecuteResponse
 
-from grebble_flow.grpc.generated.internal.v1 import processor_pb2_grpc
+from grebble_flow.grpc.generated.inner.v1 import processor_pb2_grpc
 from grebble_flow.helpers.converter import grebble_converter
 from grebble_flow.managment.manager import FlowManager
 
